@@ -4,7 +4,7 @@ from .. import database
 import datetime
 from ._apikeys import apikeystore
 
-from ..globalconf import malojaconfig
+from ..pkg_global.conf import malojaconfig
 
 
 class Listenbrainz(APIHandler):
@@ -55,6 +55,8 @@ class Listenbrainz(APIHandler):
 				try:
 					metadata = listen["track_metadata"]
 					artiststr, titlestr = metadata["artist_name"], metadata["track_name"]
+					albumstr = metadata.get("release_name")
+					additional = metadata.get("additional_info",{})
 					try:
 						timestamp = int(listen["listened_at"])
 					except Exception:
@@ -62,10 +64,21 @@ class Listenbrainz(APIHandler):
 				except Exception:
 					raise MalformedJSONException()
 
+				extrafields = {
+					# fields that will not be consumed by regular scrobbling
+					# will go into 'extra'
+					k:additional[k]
+					for k in ['track_mbid', 'release_mbid', 'artist_mbids','recording_mbid','tags']
+					if k in additional
+				}
+
 				self.scrobble({
 					'track_artists':[artiststr],
 					'track_title':titlestr,
-					'scrobble_time':timestamp
+					'album_name':albumstr,
+					'scrobble_time':timestamp,
+					'track_length': additional.get("duration"),
+					**extrafields
 				},client=client)
 
 			return 200,{"status":"ok"}
