@@ -267,6 +267,9 @@ def local_files(artist=None,artists=None,title=None):
 
 
 
+class MalformedB64(Exception):
+	pass
+
 def set_image(b64,**keys):
 	track = "title" in keys
 	if track:
@@ -279,7 +282,10 @@ def set_image(b64,**keys):
 	log("Trying to set image, b64 string: " + str(b64[:30] + "..."),module="debug")
 
 	regex = r"data:image/(\w+);base64,(.+)"
-	type,b64 = re.fullmatch(regex,b64).groups()
+	match = re.fullmatch(regex,b64)
+	if not match: raise MalformedB64()
+
+	type,b64 = match.groups()
 	b64 = base64.b64decode(b64)
 	filename = "webupload" + str(int(datetime.datetime.now().timestamp())) + "." + type
 	for folder in get_all_possible_filenames(**keys):
@@ -293,8 +299,11 @@ def set_image(b64,**keys):
 		with open(data_dir['images'](folder,filename),"wb") as f:
 			f.write(b64)
 
+
 	log("Saved image as " + data_dir['images'](folder,filename),module="debug")
 
 	# set as current picture in rotation
 	if track: set_image_in_cache(id,'tracks',os.path.join("/images",folder,filename))
 	else: set_image_in_cache(id,'artists',os.path.join("/images",folder,filename))
+
+	return os.path.join("/images",folder,filename)
